@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Annotation;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Contains a single annotation from a JSON Schema evaluation
 
-our $VERSION = '0.568';
+our $VERSION = '0.569';
 
 use 5.020;
 use Moo;
@@ -95,7 +95,7 @@ JSON::Schema::Modern::Annotation - Contains a single annotation from a JSON Sche
 
 =head1 VERSION
 
-version 0.568
+version 0.569
 
 =head1 SYNOPSIS
 
@@ -123,12 +123,12 @@ The keyword that produced the annotation.
 =head2 instance_location
 
 The path in the instance where the annotation was produced; encoded as per the JSON Pointer
-specification (L<RFC 6901|https://tools.ietf.org/html/rfc6901>).
+specification (L<RFC 6901|https://datatracker.ietf.org/doc/html/rfc6901>).
 
 =head2 keyword_location
 
 The schema path taken during evaluation to arrive at the annotation; encoded as per the JSON Pointer
-specification (L<RFC 6901|https://tools.ietf.org/html/rfc6901>).
+specification (L<RFC 6901|https://datatracker.ietf.org/doc/html/rfc6901>).
 
 =head2 absolute_keyword_location
 
